# Rationalism vs. Empiricism
## Introduction

**Epistemology** is the branch of philosophy related to the nature and scope of knowledge. It explores how knowledge can be acquired and consider its limits and validity. Rationalism and empiricism are different epistemological schools of thinking. Among other things, they differ significantly in the source of concepts and ideas. Rationalists, including *Descartes, Spinoza*, and *Leibniz*, contend that reason is a purely deductive process for achieving honest truths about reality. In contrast, empiricists, including *Locke, Berkeley*, and *Hume*, argue that knowledge derives from the role of experience and sensory data in formulating ideas. The question of what is the ideal foundation for knowledge is still debatable to this day.

The critical issues of epistemology are as follows.

- What is the nature of propositional knowledge, namely, that a particular proposition on the world is correct?
- How can we acquire knowledge?
- What are the limits of our knowledge?

Rationalism and Empiricism differ in their approaches to the answer(s) to the second question.

Empiricists have always claimed that sensory experience is the ultimate point of departure for all our knowledge. The senses, they argue, give us all our raw data about the world, and without this raw material, there would be no knowledge. Perception begins a process, and all our beliefs arise from this process. In its purest form, empiricism holds that sensory experience alone gives birth to all our beliefs and knowledge.

Rationalists have asserted that the ultimate starting point of all knowledge is not the senses but the reason. They maintain that without previous categories and principles furnished by reason, we could n't organize and explain our sense experience in any way. We would be confronted with one great kaleidoscopic whirlwind of sensation, undifferentiated, meaning nothing. Rationalism in its purest form goes so far as to consider that all our rational beliefs, and the totality of animal knowledge, consist of first principles and inborn concepts (concepts that we have just been born) which are created and accredited by reason, with anything logically deductible from these first principles.

\cite{Scheibe_2001,Meyers}


## Main Distinctions

### Innate Ideas

One of the most important differences between rationalism and empiricism is the idea of innate knowledge; that is, the knowledge that is already possessed by us when we are born. Descartes believes in the notion of inborn knowledge and proves it in his philosophy by affirming that there are specific ideas, for example, the idea of God, that we carry that are neither adventitious nor devised. Adventitious ideas refer to ideas arising from the experience of the senses, and devised ideas are ideas that we invent ourselves. Therefore, they must be inborn ideas. Both Locke and Hume decline this idea of innate knowledge by asserting that when we are born, we are born as **tabula rasa** - blank slate, and that any notion that we will ever come to possess will be the product of sensation or reflection; sensation being any stimulation by the senses from experience, and reflecting being the actual process of the mind thinking, judging, and understanding.

However, in this aspect, Locke and Hume differ a little. Locke claims what has just been said; that ideas come from sensation or reflection. Hume opposes this by telling that ideas come from impressions or experiences. In retrospect, Locke's notion of sensation is fundamentally the same as Hume's notion of impression, except that Hume asserts that the impression of something comes from an object and that impressions are separated from experience. Locke bridges the gap between sensation and experience, which is not the case with Hume. Empiricism denies the presence of essential knowledge, by showing that ideas are born purely from sensation, reflection, impressions, or experience. However, Locke's explanation of the falsity of the idea of innate knowledge is clearer in his discussion than that of Hume, because he is able to show the relationship between sensation and reflection, which Hume fails to understand. do with his impressions. experiences.

\cite{philosophy}

### Essence of Objects

Another distinction between these two philosophies is the belief in an essence behind objects. The idea of an essence or a form of all objects was believed in every theory of Plato until Descartes. Empiricism was the first philosophy that challenged this belief. Empiricism holds that all essence is extracted from experience. Hume, being the radical empiricist he is, rejects the essence and forms of things. Locke also denies the existence of species and forms, but of a smaller size than Hume. Instead, empiricism uses beam theory. What this theory asserts is that an object is a bundle of physical characteristics, devoid of any essence or form. This is really where the strict empiricist nature of Hume really reveals itself. One of the conclusions he reaches is that science and all things related to science can be refuted.

### Intuition/ Deduction Thesis

The Intuition/ Deduction thesis claims that we can know certain propositions by intuition and even more by deduction. Many empiricists(e.g., Hume) have been wanting to accept the thesis as long as it is limited to propositions solely on the relations between our concepts. We can, they agree, know intuitively that our concept of God includes our concept of omniscience. Just by analyzing the concepts, we can intellectually grasp that one consists of the other. The debate between rationalists and empiricists converges when the former affirm, and the latter argument, the Intuition/ Deduction thesis about proposals containing substantial information about the outside world.

### Innate Knowledge Thesis

The thesis of Innate Knowledge joins the thesis of Intuition/ Deduction in affirming that we have a priori knowledge, but it does not offer intuition and deduction as the cause of that knowledge. Our prior knowledge must be part of our rational nature. Experience can trigger our awareness of this knowledge, but it does not provide it. The knowledge is already there.


### Innate Concept Thesis

According to Innate Concept's thesis, some of our concepts have not been learned from experience. Rather, They are part of our rational composition, and experience triggers merely a process by which we consciously grasp them. The major concern that motivates the rationalist should now be familiar: the content of specific concepts seems to exceed anything we could have learned from experience. An example of this thought is discussed by Descartes in the Meditations. Although he sometimes seems committed to the idea that all our ideas are inborn, he classifies our ideas as weeds, devised by us, and inborn. Adventitious ideas, like the sensation of heat, are acquired directly by sensory experience. Ideas devised by us, such as our idea of a hippogriff, are created by us from other ideas we possess. Inborn ideas, such as our ideas of God, extended matter, substance and ideal triangle, are positioned in our minds by God at creation.

\cite{philosophy}

## Erasing the Boundaries from a Cognitive Science Point of View

In the genetic model, the environment is paradoxically very important. The information contained in genes can only be expressed in body structures if they are in an appropriate and complex environment - so that 99% of the information on the construction of an organism can be considered as situated in the background and only 1% in the genes themselves (the proportion is not strictly quantifiable). The environment acts as a trigger for the selective transcription of genes, which in turn affects the urgent environment. As the information in the gene is expressed in response to the structure of the situation, and the environment reacts in turn to the action of genes, the organism slowly begins to materialize. It is as if the material itself contained most of the information for life; he just needs a little extra clue.

For cognitive development, this means that genetic and environmental information simultaneously contributes to the development of cognitive structures. Some of the environmental information that stimulates certain genes can come from the senses; for example, cats can not recognize vertical lines if they are not detected before a certain age, and children who have not learned a language before the age of ten no longer retain the ability to acquire one.

More complex scenarios with intermediate control structures are also possible, as an alternative to a continuous role for genes. The rationalist argument is consistent with the genetic model in that both claim that cognition depends on fabrications that do not arise from experience. But the genetic model has historicized rationalism, playing the role of empiricism by subverting its claims to transcendental universals. Thus, the distinction between empiricism and rationalism has become mostly insignificant, as two aspects of the same coin that have melted into a sphere.



