# Philosophy *and* Religion


## Definitions

Let's look at definitions of Religion and Philosophy from Wikipedia, which are promisingly elaborate and comprehensible.

#### Religion
> There is no scholarly consensus over what precisely constitutes a religion. It may be defined as a cultural system of designated behaviors and practices, worldviews, texts, sanctified places, prophecies, ethics, or organizations, which relate humanity to the supernatural, transcendental, or spiritual. 
Different religions may or may not contain various elements ranging from the divine, sacred things, faith, a supernatural being or supernatural beings or "some ultimacy and transcendence that will provide norms and power for the rest of life". Religious practices may include rituals, sermons, commemoration or veneration (of deities), sacrifices, festivals, feasts, trances, initiations, funerary services, matrimonial services, meditation, prayer, music, art, dance, public service, or other aspects of human culture. Religions have sacred histories and narratives, which may be preserved in sacred scriptures, and symbols and holy places, that aim mostly to give a meaning to life. Religions may contain symbolic stories, which are sometimes said by followers to be true, that have the side purpose of explaining the origin of life, the Universe, and other things. Traditionally, faith, in addition to reason, has been considered a source of religious beliefs. 

\cite{wikipedia}


#### Philosophy

> Philosophy (from Greek φιλοσοφία, Philosophia, literally "love of wisdom") is the study of general and fundamental problems concerning matters such as existence, knowledge, values, reason, mind, and language. ... Philosophical methods include questioning, critical discussion, rational argument, and systematic presentation. Classic philosophical questions include: Is it possible to know anything and to prove it? What is most real? Philosophers also pose more practical and concrete questions such as: Is there a best way to live? Is it better to be just or unjust (if one can get away with it)? Do humans have free will?


\cite{wikipediaa}


So, the definitions are indeed very elaborate and tend to be all-encompassing. Though there is no scholarly consensus about what these two terms mean, we will go with the broad general view that we all sort of primarily agree with. We can (more or less) characterize the contrast between philosophy and religion in the following way: philosophy is based on reason, evidence, and experience for its truths; religion depends on faith, authority,  grace and the revelation of truth. 



## Concrete differences between Philosophy and Religion


### Epistemological Differences

As two approaches to gain knowledge about and to explain our reality, philosophy and religion are broadly different in the following ways


- **Subjects**

Religion talks about why the reality is, why we are and what we ought to do. Religion often assumes the existence of an omnipresent, omniscient, omnipotent being (**essence** in Hegelian terms) and asserts that meaning of the human life (**appearance**) shines forth from the will of that being. Religion gives the human society a set of dogmas in the form of rituals/ customs about how to best lead a meaningful life, and often these dogmas are unquestionable. 

Philosophy talks about much more broad topics and does not assume any given knowledge to be true. It generally encompasses of the disciplines like metaphysics (study of first principles and ontology), epistemology (study of the nature and scope knowledge), ethics (the study of values in human behavior or the study of moral problems), aesthetics ( the study of value in the arts or the inquiry into feelings, judgments, or standards of beauty). 


- **Toolset**

Religions are in general concocted stories about our reality and a set of guidelines to live a meaningful life. Religion thrives on collective belief of such stories and the interpersonal reality it thus creates. Religion relies highly on faith and obedience towards such *fiction* and promises that meaning to the human life arises from those set of dogmas only.

Philosophy, on the other hand, does not assume anything to *given* and questions everything. As Steven Pinker recently wrote in his book **Enlightenment Now**, Reason is non-negotiable in philosophy. Philosophy often borrows from and contributes to other branches of human endeavors and try to thrive with the most minimal set of axioms possible. Philosophy, at least in the modern times, highly relies on rationality, critical thinking, and scientific methods. \cite{pinker2018}


### Differences from a Historical point of view

- Over the past couple of millennia, Philosophy has raised some of the most profound and most important questions in human history. Philosophy has been an ever on-going and ever on-growing discipline. Most dogmatic organized religion, on the other hand, has been stagnant with the same old issues and hasn't contributed to the whole of human knowledge. 

- Philosophy, as the mother of all disciplines, has offered entire systems of thinking and propagated human knowledge in unimaginable ways. For example, what we call contemporary science, started as the study of natural philosophy only. 

- Religions apart from uniting people and providing temporary meaning to life has contributed severely negatively in the history by initiating war, xenophobia, mass hysteria and thus regimenting the development of reason, progress, science, and humanism.

- Philosophy has been empirically and pragmatically useful in the past several centuries as it tried to answer moral questions and gave frameworks for reasoning about what to value and why value that. For example, Humanism is the critical philosophical development that, we can argue, contributed significantly to the making of the contemporary world.


## Broadening the Definitions

*The following section is highly influenced by Part II of **Yuval Noah Harari**'s book **Homo Deus: A Brief History of Tomorrow**.* \cite{Harari_2017}
Let's look at philosophy and religion from a different and broader perspective. In here, we introduce **science**, and consider philosophy and religion in relation to it.


It turns out, any religious story, from the historical reality, can be summarised as

1. Ethical judgments, such as ‘human life is spiritual'. 
2. Factual statements, such as ‘human life begins at the moment of conception'. 
3. A juxtaposition of the ethical judgments with the factual statements, resulting in practical guidelines such as ‘you should never allow abortion, even a single day after conception’. 

Science can deal with the factual statements and give us objective answers about its truth value. Not to say that science already has responses to all the accounts, but it can, in theory, and has been remarkably successful at it. But, it can not talk about any ethical statements. No rule of physics or biology or whatever science can tell us that it is wrong to murder or rape a human being. 

(Note: some philosophers, most notably, contemporary neuroscientist Sam Harris believe we can use science to answer moral questions. That discussion is beyond the scope of this answer.)

Science has over and over proven incorrectness of factual statements of religion with theories such as heliocentrism and evolution. The rigidity of religion didn't let it adapt to the contemporary worldview, and thus most religions became incompatible with the current wold. Philosophy, on the other hand, came to rescue that issue and, in general, with a minimal set of assumptions, gave directions for minimizing human suffering and maximizing human flourishing.



## Case Study - Humanism

We conclude our answer with a brief overview of how the philosophy of humanism gave meaning to the human life and made human flourishing possible to the unimaginable extent possible, compared to any previously organized religion, which also tried to provide meaning for the human life.

From our previous discussions, we can summarize that:

Religion: Knowledge = Scriptures x Logic
Science: Knowledge = Empirical Data x Mathematics

Now, the development of the ideals of **Enlightenment** and **Modernity** gave birth to the philosophy of **Humanism**, which provides a new equation:

Humanism: Knowledge = Experience x Sensitivity

Humanism is a stance that emphasizes the value and agency of human beings, individually and collectively, and prefers critical thinking and evidence (rationalism and empiricism) over the acceptance of dogma or superstition. 

Where religion sources meaning of human life from the concept of an almighty God, philosophy of Humanism uses critical thinking, reason, and science to give humans the authority to choose the meaning of their life.

As an example, let's look at how different applications of humanism has improved the human condition and made human flourishing possible.

- **Humanist Politics** tells us that the voter knows the best and has authority to exercise her individuality, and doesn't have to follow the order of a monarch or religious leader.
- **Humanist Economics** tells us the market knows the best, not what a couple of leaders of a state thinks is best.
- **Humanist Aesthetics** tells us beauty lies in the eyes of the beholder. Not what a religious scripture says is beautiful, what you think is beautiful is beautiful.
- **Humanist Ethics** says if it feels good and doesn't harm anyone, do it. For example, heteronormativity is the one true path in almost all the religions of the world, while humanist philosophy has made same-sex marriages legal and acceptable in several countries already.